@@ -69,6 +69,9 @@ SERVICE_VERSIONS = {
     "bda": [
         "2020-03-24"
     ],
+    "bi": [
+        "2022-01-05"
+    ],
     "billing": [
         "2018-07-09"
     ],
@@ -121,6 +124,9 @@ SERVICE_VERSIONS = {
     "cdb": [
         "2017-03-20"
     ],
+    "cdc": [
+        "2020-12-14"
+    ],
     "cdn": [
         "2018-06-06"
     ],
